Module span

Module span 

Available on crate feature span only.
Out of the box Span for storing source code and text range.

Modules

wrapper

Structs

Span
text_size::TextRange wrapper
TextRange
A range in text, represented as a pair of TextSize.
TextSize
A measure of text length. Also, equivalently, an index into text.